pub enum Persistence {
NotPersistable = 0,
Persistable = -1,
}Expand description
Represents the persistability of a file.
Only available when the class is part of an ActiveX DLL project that is both
public and creatable.
Determines whether the class can be saved to disk.
If it is Persistable, then four procedures: InitProperties, ReadProperties, and
WriteProperties events, and the PropertyChanged method are automatically
added to the class module.
Without these procedures, the class cannot be saved to disk.
Variants
NotPersistable = 0
The class property cannot be saved to a file in a property bag. This value is stored as 0 (false) in the file.
Persistable = -1
The class property can be saved to a file in a property bag. This value is stored as -1 (true) in the file.