pub struct ClassHeader {
pub version: FileFormatVersion,
pub properties: ClassProperties,
pub attributes: FileAttributes,
}Expand description
Represents the header of a VB6 class file.
The header contains the version, multi use, persistable, data binding behavior, data source behavior, and MTS transaction mode. The header also contains the attributes of the class file.
None of these values are normally visible in the code editor region. They are only visible in the file property explorer.
Fields
version: FileFormatVersionThe version of the VB6 file format.
properties: ClassPropertiesThe properties of the class file.
attributes: FileAttributesThe attributes of the class file.