#[repr(i16)]pub enum ServerSupportFiles {
Local = 0,
Remote = 1,
}Expand description
Indicates if the project will produce the server support VBR & TLB files.
Variants
Local = 0
The project will not produce the VBR and TLB files since this is a local only project.
Remote = 1
The project will produce the VBR and TLB files needed for packaging the client applications which use this server project.