#[repr(i32)]pub enum DefaultCursorType {
Default = 0,
Odbc = 1,
ServerSide = 2,
}Expand description
Controls what type of cursor driver is used on the connection (ODBCDirect only)
created by the Data control.
Variants
Default = 0
Let the ODBC driver determine which type of cursor to use.
This is the default value.
Odbc = 1
Use the ODBC cursor library. This option gives better performance for small result sets, but degrades quickly for larger result sets.
ServerSide = 2
Use server side cursors. For most large operations this gives better performance, but might cause more network traffic.