#[repr(i32)]pub enum DrawMode {
Show 16 variants
Blackness = 1,
NotMergePen = 2,
MaskNotPen = 3,
NotCopyPen = 4,
MaskPenNot = 5,
Invert = 6,
XorPen = 7,
NotMaskPen = 8,
MaskPen = 9,
NotXorPen = 10,
Nop = 11,
MergeNotPen = 12,
CopyPen = 13,
MergePenNot = 14,
MergePen = 15,
Whiteness = 16,
}Expand description
Specifies how the pen (the color used in drawing) interacts with the background.
Variants
Blackness = 1
Black pen color is applied over the background.
NotMergePen = 2
Inversion is applied after the combination of the pen and the background color.
MaskNotPen = 3
The combination of the colors common to the background color and the inverse of the pen.
NotCopyPen = 4
Inversion is applied to the pen color.
MaskPenNot = 5
The combination of the colors common to the pen and the inverse of the background color.
Invert = 6
Inversion is applied to the background color.
XorPen = 7
The combination of the colors common to the pen and the background color, but not in both (ie, XOR).
NotMaskPen = 8
Inversion is applied to the combination of the colors common to both the pen and the background color.
MaskPen = 9
The combination of the colors common to the pen and the background color.
NotXorPen = 10
Inversion of the combination of the colors in the pen and the background color but not in both (ie, NXOR).
Nop = 11
No operation is performed. The output remains unchanged. In effect, this turns drawing off (No Operation).
MergeNotPen = 12
The combination of the display color and the inverse of the pen color.
CopyPen = 13
The color specified by the ForeColor property is applied over the background.
This is the default setting.
MergePenNot = 14
The combination of the pen color and inverse of the display color.
MergePen = 15
the combination of the pen color and the display color.
Whiteness = 16
White pen color is applied over the background.