#[repr(i32)]pub enum FormLinkMode {
None = 0,
Source = 1,
}Expand description
Determines the type of link used for a DDE conversation and activates the connection.
Forms allow a destination application to initiate a conversation with a
Visual Basic source form as specified by the destination applications
application**|topic!**item expression.
Variants
None = 0
No DDE interaction. No destination application can initiate a conversation with the source form as the topic, and no application can poke data to the form.
This is the default setting.
Source = 1
Allows any Label, PictureBox, or TextBox control on a form to supply
data to any destination application that establishes a DDE conversation
with the form. If such a link exists, Visual Basic automatically
notifies the destination whenever the contents of a control are changed.
In addition, a destination application can poke data to any Label,
PictureBox, or TextBox control on the form.