#[repr(i32)]pub enum LinkMode {
None = 0,
Automatic = 1,
Manual = 2,
Notify = 3,
}Expand description
Determines the link mode of a control for DDE conversations.
This is used with the Form control.
Variants
None = 0
No DDE interaction. No destination application can initiate a conversation with the source control as the topic, and no application can poke data to the control.
Automatic = 1
Allows any Label, PictureBox, or TextBox control on a form to supply
data to any destination application that establishes a DDE conversation
with the control. If such a link exists, Visual Basic automatically
notifies the destination whenever the contents of a control are changed.
In addition, a destination application can poke data to any Label,
PictureBox, or TextBox control on the form.
Manual = 2
Allows any Label, PictureBox, or TextBox control on a form to supply
data to any destination application that establishes a DDE conversation
with the control. However, Visual Basic does not automatically notify
the destination whenever the contents of a control are changed. In
addition, a destination application can poke data to any Label,
PictureBox, or TextBox control on the form.
Notify = 3
Allows any Label, PictureBox, or TextBox control on a form to supply
data to any destination application that establishes a DDE conversation
with the control. Visual Basic automatically notifies the destination
whenever the contents of a control are changed. However, a destination
application cannot poke data to any Label, PictureBox, or TextBox
control on the form.