pub struct CheckBoxProperties {Show 35 fields
pub alignment: JustifyAlignment,
pub appearance: Appearance,
pub back_color: Color,
pub caption: String,
pub causes_validation: CausesValidation,
pub data_field: String,
pub data_format: String,
pub data_member: String,
pub data_source: String,
pub disabled_picture: Option<ReferenceOrValue<DynamicImage>>,
pub down_picture: Option<ReferenceOrValue<DynamicImage>>,
pub drag_icon: Option<ReferenceOrValue<DynamicImage>>,
pub drag_mode: DragMode,
pub enabled: Activation,
pub font: Option<Font>,
pub fore_color: Color,
pub height: i32,
pub help_context_id: i32,
pub left: i32,
pub mask_color: Color,
pub mouse_icon: Option<ReferenceOrValue<DynamicImage>>,
pub mouse_pointer: MousePointer,
pub ole_drop_mode: OLEDropMode,
pub picture: Option<ReferenceOrValue<DynamicImage>>,
pub right_to_left: TextDirection,
pub style: Style,
pub tab_index: i32,
pub tab_stop: TabStop,
pub tool_tip_text: String,
pub top: i32,
pub use_mask_color: UseMaskColor,
pub value: CheckBoxValue,
pub visible: Visibility,
pub whats_this_help_id: i32,
pub width: i32,
}Expand description
Properties for a CheckBox control.
This is used as an enum variant of
ControlKind::CheckBox.
tag, name, and index are not included in this struct, but instead are part
of the parent Control struct.
Fields
alignment: JustifyAlignmentJustify alignment of the checkbox caption.
appearance: AppearanceAppearance of the checkbox control.
back_color: ColorBackground color of the checkbox control.
caption: StringCaption text of the checkbox control.
causes_validation: CausesValidationWhether the checkbox control causes validation.
data_field: StringData field associated with the checkbox control.
data_format: StringData format for the checkbox control.
data_member: StringData member associated with the checkbox control.
data_source: StringData source associated with the checkbox control.
disabled_picture: Option<ReferenceOrValue<DynamicImage>>Picture displayed when the checkbox is disabled.
down_picture: Option<ReferenceOrValue<DynamicImage>>Picture displayed when the checkbox is pressed down.
drag_icon: Option<ReferenceOrValue<DynamicImage>>Icon used during drag operations.
drag_mode: DragModeDrag mode of the checkbox control.
enabled: ActivationWhether the checkbox control is enabled.
font: Option<Font>The font style for the form.
fore_color: ColorForeground color of the checkbox control.
height: i32Height of the checkbox control.
help_context_id: i32Help context ID associated with the checkbox control.
left: i32Left position of the checkbox control.
mask_color: ColorMask color used for transparency.
mouse_icon: Option<ReferenceOrValue<DynamicImage>>Icon displayed when the mouse is over the checkbox control.
mouse_pointer: MousePointerMouse pointer style when hovering over the checkbox control.
ole_drop_mode: OLEDropModeOLE drop mode of the checkbox control.
picture: Option<ReferenceOrValue<DynamicImage>>Picture displayed on the checkbox control.
right_to_left: TextDirectionText direction of the checkbox control.
style: StyleStyle of the checkbox control.
tab_index: i32Tab index of the checkbox control.
tab_stop: TabStopWhether the checkbox control is included in the tab order.
tool_tip_text: StringTool tip text for the checkbox control.
top: i32Top position of the checkbox control.
use_mask_color: UseMaskColorWhether to use the mask color for transparency.
value: CheckBoxValueCurrent value/state of the checkbox control.
visible: VisibilityVisibility of the checkbox control.
whats_this_help_id: i32“What’s This?” help ID associated with the checkbox control.
width: i32Width of the checkbox control.