pub struct CommandButtonProperties {Show 29 fields
pub appearance: Appearance,
pub back_color: Color,
pub cancel: bool,
pub caption: String,
pub causes_validation: CausesValidation,
pub default: bool,
pub disabled_picture: Option<ReferenceOrValue<DynamicImage>>,
pub down_picture: Option<ReferenceOrValue<DynamicImage>>,
pub drag_icon: Option<ReferenceOrValue<DynamicImage>>,
pub drag_mode: DragMode,
pub enabled: Activation,
pub font: Option<Font>,
pub height: i32,
pub help_context_id: i32,
pub left: i32,
pub mask_color: Color,
pub mouse_icon: Option<ReferenceOrValue<DynamicImage>>,
pub mouse_pointer: MousePointer,
pub ole_drop_mode: OLEDropMode,
pub picture: Option<ReferenceOrValue<DynamicImage>>,
pub right_to_left: TextDirection,
pub style: Style,
pub tab_index: i32,
pub tab_stop: TabStop,
pub tool_tip_text: String,
pub top: i32,
pub use_mask_color: UseMaskColor,
pub whats_this_help_id: i32,
pub width: i32,
}Expand description
Properties for a CommandButton control.
This is used as an enum variant of
ControlKind::CommandButton.
tag, name, and index are not included in this struct, but instead are part
of the parent Control struct.
Fields
appearance: AppearanceThe appearance of the command button.
back_color: ColorThe background color of the command button.
cancel: boolIndicates if the button is a cancel button.
caption: StringThe caption text of the command button.
causes_validation: CausesValidationIndicates if the button causes validation.
default: boolIndicates if the button is the default button.
disabled_picture: Option<ReferenceOrValue<DynamicImage>>The picture displayed when the button is disabled.
down_picture: Option<ReferenceOrValue<DynamicImage>>The picture displayed when the button is pressed down.
drag_icon: Option<ReferenceOrValue<DynamicImage>>The icon used during drag operations.
drag_mode: DragModeThe drag mode of the command button.
enabled: ActivationIndicates if the button is enabled.
font: Option<Font>The font style for the form.
height: i32The height of the command button.
help_context_id: i32The help context ID of the command button.
left: i32The left position of the command button.
mask_color: ColorThe mask color of the command button.
mouse_icon: Option<ReferenceOrValue<DynamicImage>>The mouse icon of the command button.
mouse_pointer: MousePointerThe mouse pointer type of the command button.
ole_drop_mode: OLEDropModeThe OLE drop mode of the command button.
picture: Option<ReferenceOrValue<DynamicImage>>The picture displayed on the command button.
right_to_left: TextDirectionThe text direction of the command button.
style: StyleThe style of the command button.
tab_index: i32The tab index of the command button.
tab_stop: TabStopThe tab stop behavior of the command button.
tool_tip_text: StringThe tool tip text of the command button.
top: i32The top position of the command button.
use_mask_color: UseMaskColorIndicates if the mask color is used.
whats_this_help_id: i32The “What’s This?” help ID of the command button.
width: i32The width of the command button.