pub struct CustomControlProperties {
pub property_store: HashMap<String, String>,
}Expand description
Properties for a Custom control.
This is used to represent a non-standard control that is not part of the standard VB6 controls. This can include third-party controls and user-defined controls.
This is used as an enum variant of
ControlKind::CustomControl.
tag, name, and index are not included in this struct, but instead are part
of the parent Control struct.
Fields
property_store: HashMap<String, String>A store for the properties of the custom control.
Implementations