FileListBoxProperties

Struct FileListBoxProperties 

pub struct FileListBoxProperties {
Show 29 fields pub appearance: Appearance, pub archive: ArchiveAttribute, pub back_color: Color, pub causes_validation: CausesValidation, pub drag_icon: Option<ReferenceOrValue<DynamicImage>>, pub drag_mode: DragMode, pub enabled: Activation, pub font: Option<Font>, pub fore_color: Color, pub height: i32, pub help_context_id: i32, pub hidden: HiddenAttribute, pub left: i32, pub mouse_icon: Option<ReferenceOrValue<DynamicImage>>, pub mouse_pointer: MousePointer, pub multi_select: MultiSelect, pub normal: NormalAttribute, pub ole_drag_mode: OLEDragMode, pub ole_drop_mode: OLEDropMode, pub pattern: String, pub read_only: ReadOnlyAttribute, pub system: SystemAttribute, pub tab_index: i32, pub tab_stop: TabStop, pub tool_tip_text: String, pub top: i32, pub visible: Visibility, pub whats_this_help_id: i32, pub width: i32,
}
Properties for a FileListBox control.

This is used as an enum variant of ControlKind::FileListBox. tag, name, and index are not included in this struct, but instead are part of the parent Control struct.

Fields

appearance: Appearance

The appearance of the FileListBox.

archive: ArchiveAttribute

The archive attribute of the FileListBox.

back_color: Color

The background color of the FileListBox.

causes_validation: CausesValidation

Whether the FileListBox causes validation.

drag_icon: Option<ReferenceOrValue<DynamicImage>>

The drag icon of the FileListBox.

drag_mode: DragMode

The drag mode of the FileListBox.

enabled: Activation

Whether the FileListBox is enabled.

font: Option<Font>

The font style for the form.

fore_color: Color

The foreground color of the FileListBox.

height: i32

The height of the FileListBox.

help_context_id: i32

The help context ID of the FileListBox.

hidden: HiddenAttribute

The hidden attribute of the FileListBox.

left: i32

The left position of the FileListBox.

mouse_icon: Option<ReferenceOrValue<DynamicImage>>

The mouse icon of the FileListBox.

mouse_pointer: MousePointer

The mouse pointer of the FileListBox.

multi_select: MultiSelect

The multi-select mode of the FileListBox.

normal: NormalAttribute

The normal attribute of the FileListBox.

ole_drag_mode: OLEDragMode

The OLE drag mode of the FileListBox.

ole_drop_mode: OLEDropMode

The OLE drop mode of the FileListBox.

pattern: String

The file pattern filter of the FileListBox.

read_only: ReadOnlyAttribute

The read-only attribute of the FileListBox.

system: SystemAttribute

The system attribute of the FileListBox.

tab_index: i32

The tab index of the FileListBox.

tab_stop: TabStop

The tab stop of the FileListBox.

tool_tip_text: String

The tool tip text of the FileListBox.

top: i32

The top position of the FileListBox.

visible: Visibility

The visibility of the FileListBox.

whats_this_help_id: i32

The “What’s This?” help ID of the FileListBox.

width: i32

The width of the FileListBox.