pub type TextTokenTuple<'a> = (&'a str, Token);
Type alias for a tuple representing text and its corresponding token.
The first element of the tuple is the text slice, and the second element is the associated Token.
Token