pub struct VB6FormFile<'a> {
pub form: VB6Control,
pub objects: Vec<VB6ObjectReference<'a>>,
pub format_version: VB6FileFormatVersion,
pub attributes: VB6FileAttributes<'a>,
pub tokens: Vec<VB6Token<'a>>,
}Expand description
Represents a VB6 Form file.
Fields
form: VB6Controlobjects: Vec<VB6ObjectReference<'a>>format_version: VB6FileFormatVersionattributes: VB6FileAttributes<'a>tokens: Vec<VB6Token<'a>>Implementations
Sourceimpl<'a> VB6FormFile<'a>
impl<'a> VB6FormFile<'a>
Sourcepub fn parse_with_resolver(
form_path: String,
input: &'a [u8],
resource_resolver: impl Fn(String, usize) -> Result<Vec<u8>, Error>,
) -> Result<Self, VB6Error>
pub fn parse_with_resolver( form_path: String, input: &'a [u8], resource_resolver: impl Fn(String, usize) -> Result<Vec<u8>, Error>, ) -> Result<Self, VB6Error>
Parses a VB6 form file from a byte slice using the selected resource_file_resolver.
Arguments
file_nameThe name of the file being parsed.inputThe byte slice to parse.resource_resolverA function that resolves resource files based on their name and offset.
Returns
A result containing the parsed VB6 form file or an error.
Errors
An error will be returned if the input is not a valid VB6 form file.
Example
use vb6parse::parsers::VB6FormFile;
use vb6parse::parsers::resource_file_resolver;
let input = b"VERSION 5.00\r
Begin VB.Form frmExampleForm\r
BackColor = &H80000005&\r
Caption = \"example form\"\r
ClientHeight = 6210\r
ClientLeft = 60\r
ClientTop = 645\r
ClientWidth = 9900\r
BeginProperty Font\r
Name = \"Arial\"\r
Size = 8.25\r
Charset = 0\r
Weight = 400\r
Underline = 0 'False\r
Italic = 0 'False\r
Strikethrough = 0 'False\r
EndProperty\r
LinkTopic = \"Form1\"\r
ScaleHeight = 414\r
ScaleMode = 3 'Pixel\r
ScaleWidth = 660\r
StartUpPosition = 2 'CenterScreen\r
Begin VB.Menu mnuFile\r
Caption = \"&File\"\r
Begin VB.Menu mnuOpenImage\r
Caption = \"&Open image\"\r
End\r
End\r
End\r
Attribute VB_Name = \"frmExampleForm\"\r
";
let result = VB6FormFile::parse_with_resolver("form_parse.frm".to_owned(), &mut input.as_ref(), resource_file_resolver);
assert!(result.is_ok());pub fn parse(form_path: String, input: &'a [u8]) -> Result<Self, VB6Error>